.. TRXASprefitpack documentation master file, created by
   sphinx-quickstart on Mon Sep 27 04:37:11 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to TRXASprefitpack's documentation!
===========================================

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   math
   utility
   utility_example
   example
   TRXASprefitpack


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
